@@ -7,7 +7,7 @@ pub trait ParseValue : Parse + PartialEq {
 
 	/// Calls `Self::parse` and only returns `Ok(self)` if `self == result`.
 	fn parse_value(&self, position: &mut Position) -> Result<Self>
-	where Self : PartialEq + Clone {
+	where Self : 'static + PartialEq + Clone {
 
 		let self_maybe = Self::parse(position.clone().borrow_mut());
 
@@ -17,13 +17,7 @@ pub trait ParseValue : Parse + PartialEq {
 
 				use std::any::type_name;
 
-				let error = Error {
-
-					identifier: type_name::<Self>().to_string(),
-					position: position.clone(),
-					cause: None
-
-				};
+				let error = Error::unexpected::<Self>(position.clone());
 
 				if ok != self.clone() { Err(error) }
 				else { Ok(ok) }
