@@ -23,15 +23,7 @@ impl<const PATTERN: &'static str> Parse for Pattern<PATTERN> {
 
 	fn parse(position: &mut Position) -> Result<Self> {
 		
-		let start_position = position.clone();
-
-		let error = Error {
-
-			identifier: PATTERN.to_string(),
-			position: start_position.clone(),
-			cause: None
-
-		};
+		let error = Error::unexpected::<Self>(position.clone());
 
 		let regex_maybe = Regex::new(PATTERN);
 
@@ -51,7 +43,17 @@ impl<const PATTERN: &'static str> Parse for Pattern<PATTERN> {
 
 		let matched_string = regex_match.as_str().to_string();
 
-		for _ in 0..matched_string.len() { position.next(); }
+		for _ in 0..matched_string.len() {
+
+			if position.clone().next().is_none() {
+
+				return Err(Error::unexpected_end::<Self>(position.clone()))
+
+			}
+
+			else { let _ = position.next(); }
+
+		}
 
 		Ok(Self { matched_string })
 
